==> angular-hint-directives-0.2.3.tgz: package/hint-directives.js <==
'use strict';

var ddLibData = require('./lib/ddLib-data');

var RESTRICT_REGEXP = /restrict\s*:\s*['"](.+?)['"]/;
var customDirectives = [];
var dasherize = require('dasherize');
var search = require('./lib/search');
var checkPrelimErrors = require('./lib/checkPrelimErrors');
var getKeysAndValues = require('./lib/getKeysAndValues');
var defaultDirectives = ddLibData.directiveTypes['angular-default-directives'].directives;
var htmlDirectives = ddLibData.directiveTypes['html-directives'].directives;

angular.module('ngHintDirectives', [])
  .config(['$provide', function($provide) {
    $provide.decorator('$compile', ['$delegate', function($delegate) {
      return function(elem) {
        elem = angular.element(elem);
        for(var i = 0, length = elem.length; i < length; i+=2) {
          if(elem[i].getElementsByTagName) {
            var toSend = Array.prototype.slice.call(elem[i].getElementsByTagName('*'));
            search(toSend, customDirectives);
          }
        }
        return $delegate.apply(this, arguments);
      };
    }]);
  }]);

function supportObject(directiveObject) {
  if(typeof directiveObject === 'object') {
    var keys = Object.keys(directiveObject);
    for(var i = keys.length - 1; i >= 0; i--) {
      if(typeof directiveObject[keys[i]] === 'function') {
        return directiveObject[keys[i]];
      }
    }
  }
  return function() {};
}

var originalAngularModule = angular.module;
angular.module = function() {
  var module = originalAngularModule.apply(this, arguments);
  var originalDirective = module.directive;
  module.directive = function(directiveName, directiveFactory) {
    directiveFactory = directiveFactory || supportObject(directiveName);
    directiveName = typeof directiveName === 'string' ? directiveName : Object.keys(directiveName)[0];

    var originalDirectiveFactory = typeof directiveFactory === 'function' ? directiveFactory :
        directiveFactory[directiveFactory.length - 1];

    var factoryStr = originalDirectiveFactory.toString();

    checkPrelimErrors(directiveName, factoryStr);

    var pairs = getKeysAndValues(factoryStr);
    pairs.map(function(pair) {
      customDirectives.push(pair);
    });

    var matchRestrict = factoryStr.match(RESTRICT_REGEXP);
    var restrict = (matchRestrict && matchRestrict[1]) || 'A';
    var directive = {
      directiveName: directiveName,
      restrict: restrict,
      require: pairs
    };

    customDirectives.push(directive);

    return originalDirective.apply(this, arguments);
  };
  return module;
};

==> angular-hint-directives-0.2.4.tgz: package/hint-directives.js <==
'use strict';

var ddLibData = require('./lib/ddLib-data');

var RESTRICT_REGEXP = /restrict\s*:\s*['"](.+?)['"]/;
var customDirectives = [];
var search = require('./lib/search');
var checkPrelimErrors = require('./lib/checkPrelimErrors');
var getKeysAndValues = require('./lib/getKeysAndValues');
var defaultDirectives = ddLibData.directiveTypes['angular-default-directives'].directives;
var htmlDirectives = ddLibData.directiveTypes['html-directives'].directives;

angular.module('ngHintDirectives', [])
  .config(['$provide', function($provide) {
    $provide.decorator('$compile', ['$delegate', function($delegate) {

      var newCompile = function(elem) {
        elem = angular.element(elem);
        for(var i = 0, length = elem.length; i < length; i+=2) {
          if(elem[i].getElementsByTagName) {
            var toSend = Array.prototype.slice.call(elem[i].getElementsByTagName('*'));
            search(toSend, customDirectives);
          }
        }
        return $delegate.apply(this, arguments);
      };

      // TODO: test this
      // copy private helpers like $$addScopeInfo
      for (var prop in $delegate) {
        if ($delegate.hasOwnProperty(prop)) {
          newCompile[prop] = $delegate[prop];
        }
      }
      return newCompile;
    }]);
  }]);

function supportObject(directiveObject) {
  if(typeof directiveObject === 'object') {
    var keys = Object.keys(directiveObject);
    for(var i = keys.length - 1; i >= 0; i--) {
      if(typeof directiveObject[keys[i]] === 'function') {
        return directiveObject[keys[i]];
      }
    }
  }
  return function() {};
}

var originalAngularModule = angular.module;
angular.module = function() {
  var module = originalAngularModule.apply(this, arguments);
  var originalDirective = module.directive;
  module.directive = function(directiveName, directiveFactory) {
    directiveFactory = directiveFactory || supportObject(directiveName);
    directiveName = typeof directiveName === 'string' ? directiveName : Object.keys(directiveName)[0];

    var originalDirectiveFactory = typeof directiveFactory === 'function' ? directiveFactory :
        directiveFactory[directiveFactory.length - 1];

    var factoryStr = originalDirectiveFactory.toString();

    checkPrelimErrors(directiveName, factoryStr);

    var pairs = getKeysAndValues(factoryStr);
    pairs.map(function(pair) {
      customDirectives.push(pair);
    });

    var matchRestrict = factoryStr.match(RESTRICT_REGEXP);
    var restrict = (matchRestrict && matchRestrict[1]) || 'A';
    var directive = {
      directiveName: directiveName,
      restrict: restrict,
      require: pairs
    };

    customDirectives.push(directive);

    return originalDirective.apply(this, arguments);
  };
  return module;
};
